summaryrefslogtreecommitdiffstats
path: root/modules/mono/config.py
diff options
context:
space:
mode:
authorFabio Alessandrelli <fabio.alessandrelli@gmail.com>2022-08-28 20:27:45 +0200
committerFabio Alessandrelli <fabio.alessandrelli@gmail.com>2022-08-29 11:52:00 +0200
commitd20b32186fc192f5e527a1211291b0cb293f4e66 (patch)
tree20f5e9e84e10b68c318f576344a10a9fc63d235f /modules/mono/config.py
parent223e083d36ac1ca3f7aa46898d8870e476132f7a (diff)
downloadredot-engine-d20b32186fc192f5e527a1211291b0cb293f4e66.tar.gz
[Web] Rename JavaScript platform to Web.
Also rename export name from "HTML5" to "Web".
Diffstat (limited to 'modules/mono/config.py')
-rw-r--r--modules/mono/config.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/modules/mono/config.py b/modules/mono/config.py
index b599414a2c..ad78c8c898 100644
--- a/modules/mono/config.py
+++ b/modules/mono/config.py
@@ -1,4 +1,4 @@
# Prior to .NET Core, we supported these: ["windows", "macos", "linuxbsd", "android", "haiku", "javascript", "ios"]
# Eventually support for each them should be added back (except Haiku if not supported by .NET Core)
supported_platforms = ["windows", "macos", "linuxbsd"]
@@ -10,8 +10,8 @@ def can_build(env, platform):
def get_opts(platform):
from SCons.Variables import BoolVariable, PathVariable
- default_mono_static = platform in ["ios", "javascript"]
- default_mono_bundles_zlib = platform in ["javascript"]
+ default_mono_static = platform in ["ios", "web"]
+ default_mono_bundles_zlib = platform in ["web"]
return [
PathVariable(
@@ -1,4 +1,4 @@
-# Prior to .NET Core, we supported these: ["windows", "macos", "linuxbsd", "android", "haiku", "javascript", "ios"]
+# Prior to .NET Core, we supported these: ["windows", "macos", "linuxbsd", "android", "haiku", "web", "ios"]
# Eventually support for each them should be added back (except Haiku if not supported by .NET Core)
supported_platforms = ["windows", "macos", "linuxbsd"]